@@ -1,10 +1,12 @@
 """ This module contains a func
 and only one """
-def print_lol(the_list):
+def print_lol(the_list, level):
     """ recursive for loop """
     for each_item in the_list:
         if isinstance(each_item, list):
-            print_lol(each_item)
+            print_lol(each_item, level+1)
         else:
+            for tab_count in range(level):
+                print("\t", end='')
             print(each_item)
 
